@@ -13,7 +13,10 @@ rm -f temp/*.y
 rm -f temp/*.l
 rm -f temp/*.bat
 rm -f temp/*.sh
-rm -f temp/ickmain.exe
+rm -f temp/*.exe
+rm -f temp/*.bin
+rm -f temp/*.in
+rm -f temp/*.oil
 rm -f temp/*~
 rm -f src/*~
 rm -f *~
\ No newline at end of file
