@@ -5,7 +5,9 @@
 mv temp/parser.c temp/parser.tmp
 mv temp/parser.h temp/parserh.tmp
 mv temp/lexer.c temp/lexer.tmp
+mv temp/oil.c temp/oil.tmp
 sh cleanick.sh
 mv temp/parser.tmp temp/parser.c
 mv temp/parserh.tmp temp/parser.h
 mv temp/lexer.tmp temp/lexer.c
+mv temp/oil.tmp temp/oil.c
\ No newline at end of file
